**Example 1: 删除分类分级识别任务结果**



Input: 

```
tccli dsgc DeleteDSPADiscoveryTaskResult --cli-unfold-argument  \
    --DbResultId 1 \
    --DspaId dspa-001
```

Output: 
```
{
    "Response": {
        "RequestId": "20569756-56ba-4a13-b545-e1528d5cb239"
    }
}
```

